pub struct GitHubIdentityConnector(/* private fields */);Expand description
Represents a git hub identity connector.
Implementations
Sourceimpl GitHubIdentityConnector
impl GitHubIdentityConnector
Sourcepub fn new(
session_ttl: Duration,
principals: BTreeMap<PrincipalId, StaticPrincipalRecord>,
authorize_base_url: Option<String>,
) -> Self
pub fn new( session_ttl: Duration, principals: BTreeMap<PrincipalId, StaticPrincipalRecord>, authorize_base_url: Option<String>, ) -> Self
Creates a new value.
Sourcepub fn with_api_base_url(self, api_base_url: Option<String>) -> Self
pub fn with_api_base_url(self, api_base_url: Option<String>) -> Self
Returns a copy configured with the GitHub API base URL used for live user, org, team, and repository-access enrichment.
Sourcepub fn with_exchange_url(self, exchange_url: Option<String>) -> Self
pub fn with_exchange_url(self, exchange_url: Option<String>) -> Self
Returns a copy configured with the exchange URL.
Sourcepub fn with_token_url(self, token_url: Option<String>) -> Self
pub fn with_token_url(self, token_url: Option<String>) -> Self
Returns a copy configured with the token URL.
Sourcepub fn with_client_credentials(
self,
client_id: Option<String>,
client_secret: Option<String>,
) -> Self
pub fn with_client_credentials( self, client_id: Option<String>, client_secret: Option<String>, ) -> Self
Returns a copy configured with the client credentials.
Sourcepub fn with_redirect_uri(self, redirect_uri: Option<String>) -> Self
pub fn with_redirect_uri(self, redirect_uri: Option<String>) -> Self
Returns a copy configured with an explicit redirect URI.
Sourcepub fn with_userinfo_url(self, userinfo_url: Option<String>) -> Self
pub fn with_userinfo_url(self, userinfo_url: Option<String>) -> Self
Returns a copy configured with the userinfo URL.
Sourcepub fn with_refresh_url(self, refresh_url: Option<String>) -> Self
pub fn with_refresh_url(self, refresh_url: Option<String>) -> Self
Returns a copy configured with the refresh URL.
Sourcepub fn with_revoke_url(self, revoke_url: Option<String>) -> Self
pub fn with_revoke_url(self, revoke_url: Option<String>) -> Self
Returns a copy configured with the revoke URL.
Sourcepub fn with_jwks_url(self, jwks_url: Option<String>) -> Self
pub fn with_jwks_url(self, jwks_url: Option<String>) -> Self
Returns a copy configured with a JWKS endpoint for oidc-style token validation when a GitHub-compatible provider exposes one.
Sourcepub fn with_persist_remote_tokens(self, persist_remote_tokens: bool) -> Self
pub fn with_persist_remote_tokens(self, persist_remote_tokens: bool) -> Self
Returns a copy configured to persist upstream provider bearer/session material in durable connector state.